# Semantic Link Mapper between SHA and SKG 

## Description

Module developed within the [Auto-Twin](https://www.auto-twin-project.eu/) Horizon EU project 
to create semantic links between learned SHA features and existing SKG entities.
